@@ -108,22 +108,9 @@ class PackageView(PGChildNodeView):
         'msql': [{'get': 'msql'}, {'get': 'msql'}],
         'stats': [{'get': 'statistics'}, {'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
-        'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}]
+        'dependent': [{'get': 'dependents'}]
     })
 
-    def module_js(self):
-        """
-        This property defines whether javascript exists for this node.
-        """
-        return make_response(
-            render_template(
-                "package/js/package.js",
-                _=_
-            ),
-            200, {'Content-Type': 'application/x-javascript'}
-        )
-
     def check_precondition(action=None):
         """
         This function will behave as a decorator which will checks
@@ -150,7 +137,7 @@ class PackageView(PGChildNodeView):
                             "Connection to the server has been lost."
                         )
                     )
-                self.template_path = 'package/ppas/#{0}#'.format(
+                self.template_path = 'packages/ppas/#{0}#'.format(
                     self.manager.version)
 
                 SQL = render_template(
@@ -378,11 +365,8 @@ class PackageView(PGChildNodeView):
                     )
                 )
         data['schema'] = self.schema
-        # The SQL below will execute CREATE DDL only
-        SQL = render_template(
-            "/".join([self.template_path, 'create.sql']),
-            data=data, conn=self.conn
-        )
+
+        SQL, name = self.getSQL(gid, sid, did, data, scid, None)
 
         status, msg = self.conn.execute_scalar(SQL)
         if not status:
@@ -568,7 +552,7 @@ class PackageView(PGChildNodeView):
             status=200
         )
 
-    def getSQL(self, gid, sid, did, data, scid, pkgid=None):
+    def getSQL(self, gid, sid, did, data, scid, pkgid=None, sqltab=False):
         """
         This function will generate sql from model data.
 
@@ -584,7 +568,7 @@ class PackageView(PGChildNodeView):
             u'name'
         ]
 
-        if pkgid is not None:
+        if pkgid is not None and not sqltab:
             data['schema'] = self.schema
             SQL = render_template(
                 "/".join([self.template_path, 'properties.sql']), scid=scid,
@@ -692,7 +676,7 @@ class PackageView(PGChildNodeView):
                 res['rows'][0].setdefault(row['deftype'], []).append(priv)
 
             result = res['rows'][0]
-            sql, name = self.getSQL(gid, sid, did, result, scid, pkgid)
+            sql, name = self.getSQL(gid, sid, did, result, scid, pkgid, True)
             # Most probably this is due to error
             if not isinstance(sql, (str, unicode)):
                 return sql
