@@ -524,10 +524,20 @@ class ColumnsView(PGChildNodeView, DataTypeReader):
         Returns:
             Converted data
         """
-        if 'attlen' in data and data['attlen'] is not None:
+
+        # We need to handle the below case because jquery has changed
+        # undefined/null values to empty strings
+        # https://github.com/jquery/jquery/commit/36d2d9ae937f626d98319ed850905e8d1cbfd078
+        if 'attlen' in data and data['attlen'] == '':
+            data['attlen'] = None
+        elif 'attlen' in data and data['attlen'] is not None:
             data['attlen'] = str(data['attlen'])
-        if 'attprecision' in data and data['attprecision'] is not None:
+
+        if 'attprecision' in data and data['attprecision'] == '':
+            data['attprecision'] = None
+        elif 'attprecision' in data and data['attprecision'] is not None:
             data['attprecision'] = str(data['attprecision'])
+
         return data
 
     @check_precondition
@@ -791,6 +801,18 @@ class ColumnsView(PGChildNodeView, DataTypeReader):
                 old_data['cltype'] = self._cltype_formatter(old_data['cltype'])
                 old_data['hasSqrBracket'] = self.hasSqrBracket
 
+                if 'cltype' in data and data['cltype'] != old_data['cltype']:
+                    length, precision, typeval = \
+                        self.get_length_precision(data['cltype'])
+
+                    # if new datatype does not have length or precision
+                    # then we cannot apply length or precision of old
+                    # datatype to new one.
+                    if not length:
+                        old_data['attlen'] = -1
+                    if not precision:
+                        old_data['attprecision'] = None
+
             # If name is not present in data then
             # we will fetch it from old data, we also need schema & table name
             if 'name' not in data:
@@ -970,9 +992,15 @@ class ColumnsView(PGChildNodeView, DataTypeReader):
             clid: Column ID
 
         """
+
+        # Specific condition for column which we need to append
+        where = "WHERE dep.objid={0}::OID AND dep.objsubid={1}".format(
+            tid, clid
+        )
+
         # Specific condition for column which we need to append
         dependencies_result = self.get_dependencies(
-            self.conn, clid
+            self.conn, clid, where
         )
 
         return ajax_response(
