@@ -32,6 +32,10 @@ class TestTriggerNodesSql(SQLTemplateTestBase):
     def generate_sql(self, version):
         file_path = os.path.join(os.path.dirname(__file__), "..", "templates",
                                  "triggers", "sql")
+        if 'type' in self.server:
+            file_path = os.path.join(os.path.dirname(__file__), "..",
+                                     "templates",
+                                     "triggers", "sql", self.server['type'])
         template_file = self.get_template_file(version, file_path,
                                                "nodes.sql")
         template = file_as_template(template_file)
