@@ -22,6 +22,55 @@ from pgadmin.utils.exception import ConnectionLost, SSHTunnelConnectionLost,\
     CryptKeyMissing
 
 
+def underscore_escape(text):
+    """
+    This function mimics the behaviour of underscore js escape function
+    The html escaped by jinja is not compatible for underscore unescape
+    function
+    :param text: input html text
+    :return: escaped text
+    """
+    html_map = {
+        '&': "&amp;",
+        '<': "&lt;",
+        '>': "&gt;",
+        '"': "&quot;",
+        '`': "&#96;",
+        "'": "&#x27;"
+    }
+
+    # always replace & first
+    for c, r in sorted(html_map.items(),
+                       key=lambda x: 0 if x[0] == '&' else 1):
+        text = text.replace(c, r)
+
+    return text
+
+
+def underscore_unescape(text):
+    """
+    This function mimics the behaviour of underscore js unescape function
+    The html unescape by jinja is not compatible for underscore escape
+    function
+    :param text: input html text
+    :return: unescaped text
+    """
+    html_map = {
+        "&amp;": '&',
+        "&lt;": '<',
+        "&gt;": '>',
+        "&quot;": '"',
+        "&#96;": '`',
+        "&#x27;": "'"
+    }
+
+    # always replace & first
+    for c, r in html_map.items():
+        text = text.replace(c, r)
+
+    return text
+
+
 def is_version_in_range(sversion, min_ver, max_ver):
     assert (max_ver is None or isinstance(max_ver, int))
     assert (min_ver is None or isinstance(min_ver, int))
@@ -461,10 +510,12 @@ class PGChildNodeView(NodeView):
             'S': 'sequence',
             'v': 'view',
             'x': 'external_table',
-            'p': 'function',
+            'p': 'partition',
+            'P': 'function',
             'n': 'schema',
             'y': 'type',
             'd': 'domain',
+            't': 'trigger_function',
             'T': 'trigger',
             'l': 'language',
             'f': 'foreign_data_wrapper',
@@ -500,6 +551,7 @@ class PGChildNodeView(NodeView):
                 ref_name = nsp_name + '.'
 
             type_name = ''
+            icon = None
 
             # Fetch the type name from the dictionary
             # if type is not present in the types dictionary then
@@ -514,6 +566,25 @@ class PGChildNodeView(NodeView):
                             type_name = 'column'
                         else:
                             type_name = 'table'
+                            if 'is_inherits' in row \
+                                    and row['is_inherits'] == '1':
+                                if 'is_inherited' in row \
+                                        and row['is_inherited'] == '1':
+                                    icon = 'icon-table-multi-inherit'
+                                # For tables under partitioned tables,
+                                # is_inherits will be true and dependency
+                                # will be auto as it inherits from parent
+                                # partitioned table
+                                elif ('is_inherited' in row and
+                                      row['is_inherited'] == '0')\
+                                        and dep_str == 'a':
+                                    type_name = 'partition'
+                                else:
+                                    icon = 'icon-table-inherits'
+                            elif 'is_inherited' in row \
+                                    and row['is_inherited'] == '1':
+                                icon = 'icon-table-inherited'
+
                     elif type_str[0] == 'R':
                         type_name = 'rule'
                         ref_name = \
@@ -569,7 +640,8 @@ class PGChildNodeView(NodeView):
                 {
                     'type': type_name,
                     'name': ref_name,
-                    'field': dep_type
+                    'field': dep_type,
+                    'icon': icon,
                 }
             )
 
