@@ -7,6 +7,7 @@
 #
 ##########################################################################
 
+from __future__ import print_function
 import pyperclip
 import random
 
@@ -14,6 +15,7 @@ from selenium.webdriver import ActionChains
 from selenium.webdriver.common.keys import Keys
 from regression.python_test_utils import test_utils
 from regression.feature_utils.base_feature_test import BaseFeatureTest
+from regression.feature_utils.locators import QueryToolLocators
 
 
 class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
@@ -32,10 +34,9 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
         # Create test table with random name to avoid same name conflicts in
         # parallel execution
         self.test_table_name = "test_table" + str(random.randint(1000, 3000))
-
+        self.page.add_server(self.server)
         test_utils.create_table(
             self.server, self.test_db, self.test_table_name)
-        self.page.add_server(self.server)
 
     def runTest(self):
         self.page.toggle_open_tree_item(self.server['name'])
@@ -46,7 +47,8 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
         self.page.fill_codemirror_area_with(
             "SELECT * FROM %s ORDER BY some_column" % self.test_table_name)
 
-        self.page.find_by_id("btn-flash").click()
+        self.page.find_by_css_selector(
+            QueryToolLocators.btn_execute_query_css).click()
 
         self._copies_rows()
         self._copies_columns()
@@ -59,21 +61,26 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
 
     def _copies_rows(self):
         pyperclip.copy("old clipboard contents")
-        self.page.find_by_xpath(
-            "//*[contains(@class, 'slick-row')]/*[1]").click()
+        first_row = self.page.find_by_xpath(
+            QueryToolLocators.output_row_xpath.format(1))
+        first_row.click()
 
-        self.page.find_by_xpath("//*[@id='btn-copy-row']").click()
+        copy_button = self.page.find_by_css_selector(
+            QueryToolLocators.copy_button_css)
+        copy_button.click()
 
         self.assertEqual('"Some-Name"\t"6"\t"some info"',
                          pyperclip.paste())
 
     def _copies_columns(self):
         pyperclip.copy("old clipboard contents")
-        self.page.find_by_xpath(
-            "//*[@data-test='output-column-header' and "
-            "contains(., 'some_column')]"
-        ).click()
-        self.page.find_by_xpath("//*[@id='btn-copy-row']").click()
+        column = self.page.find_by_css_selector(
+            QueryToolLocators.output_column_header_css.format('some_column'))
+        column.click()
+
+        copy_button = self.page.find_by_css_selector(
+            QueryToolLocators.copy_button_css)
+        copy_button.click()
 
         self.assertEqual(
             """\"Some-Name"
@@ -83,8 +90,9 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
 
     def _copies_row_using_keyboard_shortcut(self):
         pyperclip.copy("old clipboard contents")
-        self.page.find_by_xpath(
-            "//*[contains(@class, 'slick-row')]/*[1]").click()
+        first_row = self.page.find_by_xpath(
+            QueryToolLocators.output_row_xpath.format(1))
+        first_row.click()
 
         ActionChains(self.page.driver).key_down(
             Keys.CONTROL).send_keys('c').key_up(Keys.CONTROL).perform()
@@ -94,10 +102,9 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
 
     def _copies_column_using_keyboard_shortcut(self):
         pyperclip.copy("old clipboard contents")
-        self.page.find_by_xpath(
-            "//*[@data-test='output-column-header' and "
-            "contains(., 'some_column')]"
-        ).click()
+        column = self.page.find_by_css_selector(
+            QueryToolLocators.output_column_header_css.format('some_column'))
+        column.click()
 
         ActionChains(self.page.driver).key_down(
             Keys.CONTROL).send_keys('c').key_up(Keys.CONTROL).perform()
@@ -111,12 +118,12 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
     def _copies_rectangular_selection(self):
         pyperclip.copy("old clipboard contents")
 
-        top_left_cell = self.page.find_by_xpath(
-            "//div[contains(@class, 'slick-cell') and "
-            "contains(., 'Some-Other-Name')]"
-        )
+        top_left_cell = \
+            self.page.find_by_xpath(
+                QueryToolLocators.output_column_data_xpath.
+                format('Some-Other-Name'))
         bottom_right_cell = self.page.find_by_xpath(
-            "//div[contains(@class, 'slick-cell') and contains(., '14')]")
+            QueryToolLocators.output_column_data_xpath.format('14'))
 
         ActionChains(
             self.page.driver
@@ -135,11 +142,11 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
         pyperclip.copy("old clipboard contents")
 
         top_left_cell = self.page.find_by_xpath(
-            "//div[contains(@class, 'slick-cell') and "
-            "contains(., 'Some-Other-Name')]"
+            QueryToolLocators.output_column_data_xpath.
+            format('Some-Other-Name')
         )
         initial_bottom_right_cell = self.page.find_by_xpath(
-            "//div[contains(@class, 'slick-cell') and contains(., '14')]")
+            QueryToolLocators.output_column_data_xpath.format('14'))
         ActionChains(
             self.page.driver
         ).click_and_hold(top_left_cell).move_to_element(
@@ -160,10 +167,10 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
     def _shift_resizes_column_selection(self):
         pyperclip.copy("old clipboard contents")
 
-        self.page.find_by_xpath(
-            "//*[@data-test='output-column-header' and "
-            "contains(., 'value')]"
-        ).click()
+        column = self.page.find_by_css_selector(
+            QueryToolLocators.output_column_header_css.format('value')
+        )
+        column.click()
 
         ActionChains(self.page.driver).key_down(
             Keys.SHIFT).send_keys(Keys.ARROW_LEFT).key_up(Keys.SHIFT).perform()
@@ -181,11 +188,11 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
         pyperclip.copy("old clipboard contents")
 
         bottom_right_cell = self.page.find_by_xpath(
-            "//div[contains(@class, 'slick-cell') and "
-            "contains(., 'cool info')]"
+            QueryToolLocators.output_column_data_xpath.format('cool info')
         )
 
-        load_button = self.page.find_by_xpath("//button[@id='btn-load-file']")
+        load_button = self.page.find_by_css_selector(
+            QueryToolLocators.btn_load_file_css)
         ActionChains(self.page.driver).click_and_hold(bottom_right_cell) \
             .move_to_element(load_button) \
             .release(load_button) \
@@ -199,3 +206,5 @@ class CopySelectedQueryResultsFeatureTest(BaseFeatureTest):
     def after(self):
         self.page.close_query_tool()
         self.page.remove_server(self.server)
+        test_utils.delete_table(self.server, self.test_db,
+                                self.test_table_name)
