@@ -690,7 +690,7 @@ define([
 
       this.$el.append(
         $('<input>', {
-          tabIndex: -1,
+          tabIndex: 0,
           type: 'checkbox',
         }).prop('checked', rawValue).prop('disabled', !editable).attr('data-toggle', 'toggle')
           .attr('data-size', options.size).attr('data-on', options.onText).attr('data-off', options.offText)
@@ -726,13 +726,17 @@ define([
             } else if (gotoCell.hasClass('editable')) {
               e.preventDefault();
               e.stopPropagation();
-              self.model.trigger('backgrid:edited', self.model,
-                self.column, command);
+              setTimeout(function() {
+                self.model.trigger('backgrid:edited', self.model,
+                  self.column, command);
+              }, 10);
               gotoCell.trigger('focus');
             } else {
               // When we have Non-Editable Cell
-              self.model.trigger('backgrid:edited', self.model,
-                self.column, command);
+              setTimeout(function() {
+                self.model.trigger('backgrid:edited', self.model,
+                  self.column, command);
+              }, 10);
             }
           }, 20);
         }
@@ -1751,6 +1755,7 @@ define([
             },
           },
         });
+      this.tabKeyPress = false;
       this.$el.datetimepicker(options);
       this.$el.datetimepicker('show');
       this.picker = this.$el.data('DateTimePicker');
@@ -1758,27 +1763,41 @@ define([
     events: {
       'hide.datetimepicker': 'closeIt',
       'focusout':'closeIt',
+      'keydown': 'keydownHandler',
     },
-    closeIt: function(ev) {
+    keydownHandler: function(event) {
+      // If Tab key pressed from Cell and not from Datetime picker element
+      // then we should trigger edited event so that we can goto next cell
+      let self = this;
+      let tabKeyPressed = true;
+      if (event.keyCode === 9 && self.el === event.target) {
+        self.closeIt(event, tabKeyPressed);
+      }
+    },
+    closeIt: function(ev, isTabKeyPressed) {
+      if (this.is_closing || this.tabKeyPress)
+        return;
+
+      this.is_closing = true;
+      this.tabKeyPress = isTabKeyPressed;
+
       var formatter = this.formatter,
         model = this.model,
         column = this.column,
         val = this.$el.val(),
         newValue = formatter.toRaw(val, model);
 
-      if (this.is_closing)
-        return;
-      this.is_closing = true;
       this.$el.datetimepicker('destroy');
       this.is_closing = false;
 
-      var command = new Backgrid.Command(ev);
-
       if (_.isUndefined(newValue)) {
         model.trigger('backgrid:error', model, column, val);
       } else {
         model.set(column.get('name'), newValue);
-        model.trigger('backgrid:edited', model, column, command);
+        let command = new Backgrid.Command(ev);
+        setTimeout(() => {
+          model.trigger('backgrid:edited', model, column, command);
+        }, 20);
       }
     },
   });
