@@ -199,3 +199,9 @@ export function fully_qualify(pgBrowser, data, item) {
     return quote_ident(data._label);
   }
 }
+
+export function getRandomInt(min, max) {
+  min = Math.ceil(min);
+  max = Math.floor(max);
+  return Math.floor(Math.random() * (max - min + 1)) + min;
+}
