@@ -194,6 +194,35 @@ def create_table(server, db_name, table_name, extra_columns=[]):
         traceback.print_exc(file=sys.stderr)
 
 
+def delete_table(server, db_name, table_name):
+    """
+    This function delete the table in given database
+    :param server: server details
+    :type server: dict
+    :param db_name: database name
+    :type db_name: str
+    :param table_name: table name
+    :type table_name: str
+    :return: None
+    """
+    try:
+        connection = get_db_connection(
+            db_name,
+            server['username'],
+            server['db_password'],
+            server['host'],
+            server['port'],
+            server['sslmode']
+        )
+        pg_cursor = connection.cursor()
+        pg_cursor.execute(
+            '''DROP TABLE IF EXISTS "%s"''' % table_name)
+        connection.commit()
+
+    except Exception:
+        traceback.print_exc(file=sys.stderr)
+
+
 def create_table_with_query(server, db_name, query):
     """
     This function create the table in given database name
@@ -255,6 +284,44 @@ def create_constraint(server,
         traceback.print_exc(file=sys.stderr)
 
 
+def create_type(server, db_name, type_name, type_fields=[]):
+    """
+    This function create the type in given database name
+    :param server: server details
+    :type server: dict
+    :param db_name: database name
+    :type db_name: str
+    :param type_name: type name
+    :type type_name: str
+    :param type_fields: type fields
+    :type type_fields: list
+    :return: None
+    """
+    try:
+        connection = get_db_connection(
+            db_name,
+            server['username'],
+            server['db_password'],
+            server['host'],
+            server['port'],
+            server['sslmode']
+        )
+        old_isolation_level = connection.isolation_level
+        connection.set_isolation_level(0)
+
+        type_fields_sql = ", ".join(type_fields)
+
+        pg_cursor = connection.cursor()
+        pg_cursor.execute(
+            '''CREATE TYPE %s AS (%s)''' % (type_name, type_fields_sql))
+
+        connection.set_isolation_level(old_isolation_level)
+        connection.commit()
+
+    except Exception:
+        traceback.print_exc(file=sys.stderr)
+
+
 def create_debug_function(server, db_name, function_name="test_func"):
     try:
         connection = get_db_connection(
@@ -736,22 +803,28 @@ def configure_preferences(default_binary_path=None):
 
 
 def reset_layout_db(user_id=None):
-    conn = sqlite3.connect(config.TEST_SQLITE_PATH)
-    cur = conn.cursor()
+    retry = 3
+    while retry > 0:
+        try:
+            conn = sqlite3.connect(config.TEST_SQLITE_PATH)
+            cur = conn.cursor()
 
-    if user_id is None:
-        cur.execute(
-            'DELETE FROM SETTING WHERE SETTING in '
-            '("Browser/Layout", "SQLEditor/Layout", "Debugger/Layout")'
-        )
-    else:
-        cur.execute(
-            'DELETE FROM SETTING WHERE SETTING in '
-            '("Browser/Layout", "SQLEditor/Layout", "Debugger/Layout")'
-            ' AND USER_ID=?', user_id
-        )
-    conn.commit()
-    conn.close()
+            if user_id is None:
+                cur.execute(
+                    'DELETE FROM SETTING WHERE SETTING in '
+                    '("Browser/Layout", "SQLEditor/Layout", "Debugger/Layout")'
+                )
+            else:
+                cur.execute(
+                    'DELETE FROM SETTING WHERE SETTING in '
+                    '("Browser/Layout", "SQLEditor/Layout", "Debugger/Layout")'
+                    ' AND USER_ID=?', user_id
+                )
+            conn.commit()
+            conn.close()
+            break
+        except Exception:
+            retry -= 1
 
 
 def remove_db_file():
@@ -1042,3 +1115,8 @@ def get_watcher_dialogue_status(self):
         else:
             break
     return status
+
+
+def get_driver_version():
+    version = getattr(psycopg2, '__version__', None)
+    return version
